abacusai.database_connector_schema — AbacusAI documentation

# abacusai.database_connector_schema

## Classes

`DatabaseConnectorColumn` | A schema description for a column from a database connector
`AbstractApiClass` |
`DatabaseConnectorSchema` | A schema description for a table from a database connector

## Module Contents

class abacusai.database_connector_schema.DatabaseConnectorColumn(client, name=None, externalDataType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a column from a database connector

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column.

    - externalDataType (str) – The data type of column in the external database system.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.database_connector_schema.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.database_connector_schema.DatabaseConnectorSchema(client, tableName=None, columns={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a table from a database connector

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - tableName (str) – The unique name of the table.

    - columns (DatabaseConnectorColumn) – List of columns in the table.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict